@@ -16,7 +16,16 @@ import copy
 from . import __version__
 
 f2py_version = __version__.version
-errmess = sys.stderr.write
+
+
+def errmess(s: str) -> None:
+    """
+    Write an error message to stderr.
+
+    This indirection is needed because sys.stderr might not always be available (see #26862).
+    """
+    if sys.stderr is not None:
+        sys.stderr.write(s)
 
 ##################### Definitions ##################
 
